#
# spec file for package argocd-cli
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define __arch_install_post export NO_BRP_STRIP_DEBUG=true

%define executable_name argocd

Name:           argocd-cli
Version:        2.9.6
Release:        1.1
Summary:        CLI for the ArgoCD declarative continuous deployment tool
License:        Apache-2.0
URL:            https://github.com/argoproj/argo-cd
Source:         argo-cd-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  go >= 1.20

%description
Argo CD is a declarative, GitOps continuous delivery tool for Kubernetes.

This packages contains the CLI to interact with the ArgoCD installation in a Kubernetes cluster.

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%autosetup -p 1 -a 1 -n argo-cd-%{version}

%build
KUBECTL_VERSION=$(awk '/=> k8s.io\/kubectl v/ {print $4}' go.mod)
DATE_FMT="+%%Y-%%m-%%dT%%H:%%M:%%SZ"
BUILD_DATE=$(date -u -d "@${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u -r "${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u "${DATE_FMT}")
go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags="\
   -X github.com/argoproj/argo-cd/v2/common.version=%{version} \
   -X github.com/argoproj/argo-cd/v2/common.buildDate=$BUILD_DATE \
   -X github.com/argoproj/argo-cd/v2/common.gitCommit=v%{version} \
   -X github.com/argoproj/argo-cd/v2/common.gitTag=v%{version} \
   -X github.com/argoproj/argo-cd/v2/common.gitTreeState=clean \
   -X github.com/argoproj/argo-cd/v2/common.kubectlVersion=$KUBECTL_VERSION" \
   -o bin/%{executable_name} ./cmd/

%install
# Install the binary.
install -D -m 0755 bin/%{executable_name} "%{buildroot}/%{_bindir}/%{executable_name}"

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/%{executable_name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{executable_name}

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh_completion.d/
%{buildroot}/%{_bindir}/%{executable_name} completion zsh > %{buildroot}%{_datarootdir}/zsh_completion.d/_%{executable_name}

%files
%doc README.md
%license LICENSE
%{_bindir}/%{executable_name}

%files -n %{name}-bash-completion
%dir %{_datarootdir}/bash-completion/completions/
%{_datarootdir}/bash-completion/completions/%{executable_name}

%files -n %{name}-zsh-completion
%defattr(-,root,root)
%dir %{_datarootdir}/zsh_completion.d/
%{_datarootdir}/zsh_completion.d/_%{executable_name}

%changelog
* Sat Feb  3 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.9.6:
  * Bump version to 2.9.6 (#17078)
  * chore(deps): rm go-jose Cxb6dee8d5-b814 high vuln (#16947)
    (#16970) (#17056)
  * fix(redis): go-redis v9 regression missing metrics and
    reconnect hook (#13415) (#15275) (#17024)
  * fix(ui): Badge for apps in any namespace (#16739) (#17008)
  * fix(server): allow disabling content-type check (#16959)
    (#16977)
* Sat Jan 20 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.9.5:
  * Bump version to 2.9.5 (#16937)
  * fix(ui): set content-type for certain UI requests (#16923)
    (#16930) (#16933)
* Sat Jan 20 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.9.4:
  * Bump version to 2.9.4 (#16917)
  * chore(deps): bump github.com/go-git/go-git/v5 from 5.8.1 to
    5.11.0 (#16912)
  * fix: enforce content type header for API requests (#16860)
    (Cherry-pick release-2.9 ) (#16878)
  * fix: add list permission deployments (#16785) (#16804)
  * fix(ui):Fixed log horizontal scroll for issue #16411 (#16727)
    (#16761)
  * fix(action): Add missing owner refs and annotation to
    create-job action (#16607) (#16608)
  * Added missing 'alias:' prefix for repository name as described
    here: (#15902) (#16535)
  * fix(grpcproxy): add missing GRPCKeepAliveEnforcementMinimum
    (#15708) (#16576)
  * fix(appset): don't emit k8s events for unchanged apps, log at
    debug (#16562)
  * docs: Fix format issue in rbac.md (#16521) (#16538)
  * chore: upgrade k8s client from v0.24.2 to v0.24.17 (#16554)
  * fix(appset): Don't use revision cache when reconciling after
    webhook (#16062) (#16241) (#16536)
* Sun Dec  3 2023 kastl@b1-systems.de
- Update to version 2.9.3:
  * Bump version to 2.9.3 (#16510)
  * fix(repo-server): excess git requests, resolveReferencedSources
    and runManifestGenAsync not using cache (Issue #14725) (#16410)
    (#16494)
  * fix(controller): Address diff cache miss issues (#16458)
    (#16485)
  * fix: cherry-pick fixed cli admin dashboard cmd (#16457)
  * fix(ui): Issues with overlapping content in the app details
    view on smaller screens (#16268) (#16407)
* Tue Nov 21 2023 kastl@b1-systems.de
- Update to version 2.9.2:
  * Bump version to 2.9.2 (#16405)
  * feat: add support for ALL_PROXY (#10451) (#16401)
  * fix: set max for max cookie number to `math.MaxInt` (#16388)
    (#16397)
  * docs: fix documentation of ignoreApplicationDifferences
    (#16365) (#16380)
  * bump helm 3.13.2 (#16344)
  * fix: check for double definition (#16335)
  * docs: fix upgrade instructions (#16327)
* Fri Nov 17 2023 Johannes Kastl <kastl@b1-systems.de>
- new package argocd-cli: CLI for the ArgoCD declarative continuous
  deployment tool
